import React from 'react';
import { render, cleanup, fireEvent } from '@testing-library/react';
import '@testing-library/jest-dom/extend-expect';

import '~tests/helpers/match-media.mock';
import PaginationItem from '.';

const currentSlide = 3;

describe('Pagination Item Component', () => {
  test('render pagination item', () => {
    const { container } = render(
      <PaginationItem slideIndex={currentSlide} type="dots" totalSlides={5} />
    );
    expect(container.querySelectorAll('button.paginationItem')).toHaveLength(5);
    expect(container.querySelectorAll('button.paginationItem.active')).toHaveLength(1);
  });
  test('on click', () => {
    const paginationClick = jest.fn();

    const { container } = render(
      <PaginationItem
        slideIndex={currentSlide}
        type="dots"
        totalSlides={5}
        paginationHandler={paginationClick}
      />
    );
    const paginationItemBtn = container.querySelector('button.paginationItem.active');
    fireEvent.click(paginationItemBtn);
    fireEvent.keyDown(paginationItemBtn);
    expect(paginationClick).toHaveBeenCalled();
    expect(paginationClick).toHaveBeenCalledWith(3);
  });

  test('render empty', () => {
    const { container } = render(<PaginationItem totalSlides={0} />);
    expect(container.querySelector('button')).toBeFalsy();
  });
});
afterEach(() => {
  cleanup();
});
