import React from 'react';
import {
  Title,
  Description,
  Primary,
  PRIMARY_STORY,
  ArgsTable,
} from '@storybook/addon-docs/blocks';

import Slider from '.';
import LazyImage from '~hooks/lazy-image';
import keygen from '~helpers/keygen';
import Arrow from '~atoms/carousel/arrow';
import Slide1 from '../../../../static/images/slide-1.png';
import Slide2 from '../../../../static/images/slide-2.jpg';
import Slide3 from '../../../../static/images/slide-3.jpg';
import styles from './slider.module.scss';

export default {
  title: 'Theme/Molecules/Slider',
  component: Slider,
  argTypes: {
    useArrows: {
      name: 'useArrows',
      type: { name: 'boolean', required: false },
      defaultValue: true,
      description: 'Use arrow navigation.',
      table: {
        type: { summary: 'boolean' },
        defaultValue: { summary: true },
      },
    },
    usePagination: {
      name: 'usePagination',
      type: { name: 'boolean', required: false },
      defaultValue: true,
      description: 'Use pagination navigation.',
      table: {
        type: { summary: 'boolean' },
        defaultValue: { summary: true },
      },
    },
    arrows: {
      name: 'arrows',
      type: { name: 'object', required: false },
      defaultValue: '',
      description: 'The previous and next button element.',
      table: {
        type: { summary: 'object of elements' },
        defaultValue: {
          summary: "{prev:<Arrow direction='left' />, next:<Arrow direction='right' />}",
        },
      },
      control: {
        type: null,
      },
    },
    settings: {
      name: 'settings',
      type: { name: 'object', required: false },
      defaultValue: '',
      description: 'The slider settings.',
      table: {
        type: { summary: 'object' },
        defaultValue: {
          summary: `{
            swipeEndThreshold: 0.25,
            transitionTime: 400,
            numberOfSlides: 1,
            sliderGap: 0,
          }`,
        },
      },
    },
    className: {
      name: 'className',
      type: { name: 'string', required: false },
      defaultValue: '',
      description: 'The slider container class name.',
      table: {
        type: { summary: 'string' },
        defaultValue: {
          summary: '',
        },
      },
    },
    children: {
      name: 'children',
      type: { name: 'array', required: true },
      defaultValue: ``,
      description: 'The slides used.',
      table: {
        type: { summary: 'array of elements' },
        defaultValue: { summary: `` },
      },
      control: {
        type: null,
      },
    },
  },
  parameters: {
    docs: {
      description: {
        component:
          'Provides a sliding feature that can be used by a Carousel. The sliding can be controlled by the use of arrows, pagination, mouse or touch events.',
      },
      page: () => (
        <>
          <Title />
          <Description />
          <Primary />
          <ArgsTable story={PRIMARY_STORY} />
        </>
      ),
    },
  },
};

const list = [
  {
    title: 'slide one',
    text: "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,",
    image: Slide1,
  },
  {
    title: 'slide two',
    text: 'Lorem Ipsum is simply dummy text of the printing and typesetting industry',
    image: Slide2,
  },
  {
    title: 'slide three',
    text: 'Lorem Ipsum is simply dummy text of the printing and typesetting industry',
    image: Slide3,
  },
];
const Template = (args) => (
  <div className={styles.sliderStorybookContainer}>
    <Slider {...args}>
      {list.map((item) => {
        return (
          <div key={keygen()} className={styles.item}>
            <h4>{item.title}</h4>
            <LazyImage alt={item.title} src={item.image} />
            <p>{item.text}</p>
          </div>
        );
      })}
    </Slider>
  </div>
);

export const Default = Template.bind({});
Default.args = {
  useArrows: true,
  usePagination: true,
  arrows: {
    prev: <Arrow direction="left" />,
    next: <Arrow direction="right" />,
  },
  settings: {
    swipeEndThreshold: 0.25,
    transitionTime: 400,
    numberOfSlides: 1,
    sliderGap: 0,
  },
  className: '',
};
