import React from 'react';
import { render, cleanup, fireEvent, waitFor } from '@testing-library/react';
import '@testing-library/jest-dom/extend-expect';
import keygen from '~helpers/keygen';
import Slider from '.';

/* eslint-disable no-underscore-dangle */

describe('Slider Component', () => {
  test('Row Swipe', async () => {
    const list = ['Summer', 'Autumn', 'Winter', 'Spring'];

    const { container } = render(
      <Slider useArrows={false} usePagination={false} settings={{ numberOfSlides: 0 }}>
        {list.map((element) => (
          <div key={keygen()}>{element}</div>
        ))}
      </Slider>
    );

    const content = container.querySelector('div.sliderContent');
    fireEvent.mouseDown(content, { clientX: 0 });
    fireEvent.mouseMove(content, { clientX: 1000 });
    fireEvent.mouseUp(content, { clientX: 1000 });
  });

  test('Render Row Slider', async () => {
    const list = ['Summer', 'Autumn', 'Winter', 'Spring'];
    const { container } = render(
      <Slider useArrows={false} usePagination={false} settings={{ numberOfSlides: 0 }}>
        {list.map((element) => (
          <div key={keygen()}>{element}</div>
        ))}
      </Slider>
    );

    const prev = container.querySelector('button.left');
    const next = container.querySelector('button.right');
    const dots = container.querySelector('div.pagination');
    const content = container.querySelector('div.sliderContent');
    expect(prev).toBeFalsy();
    expect(next).toBeFalsy();
    expect(dots).toBeFalsy();
    expect(content).toBeTruthy();
  });

  test('Render Slide Slider', async () => {
    const list = ['Summer', 'Autumn', 'Winter', 'Spring'];
    const { container } = render(
      <Slider>
        {list.map((element) => (
          <div key={keygen()}>{element}</div>
        ))}
      </Slider>
    );

    const prev = container.querySelector('button.left');
    const next = container.querySelector('button.right');

    await waitFor(() => {
      const dots = container.querySelector('div.pagination');
      expect(dots).toBeTruthy();
    });

    const content = container.querySelector('div.sliderContent');

    expect(prev).toBeTruthy();
    expect(next).toBeTruthy();
    expect(content).toBeTruthy();
    expect(content.querySelector('.active>div').innerHTML).toBe('Summer');
  });

  test('Navigate and Paginate', async () => {
    const list = ['Summer', 'Autumn', 'Winter', 'Spring'];

    const { container } = render(
      <Slider>
        {list.map((element) => (
          <div key={keygen()}>{element}</div>
        ))}
      </Slider>
    );

    const prev = container.querySelector('button.left');
    const next = container.querySelector('button.right');

    const content = container.querySelector('div.sliderContent');

    fireEvent.click(next);
    expect(content.querySelector('.active>div').innerHTML).toBe('Autumn');

    fireEvent.click(prev);
    expect(content.querySelector('.active>div').innerHTML).toBe('Summer');

    await waitFor(() => {
      const dots = container.querySelector('div.pagination');
      const dot = dots.querySelectorAll('button');
      expect(dot.length).toEqual(4);
      fireEvent.click(dot[1]);
      expect(content.querySelector('.active>div').innerHTML).toBe('Autumn');
    });
  });

  test('Swipe Slides', async () => {
    const list = ['Summer', 'Autumn', 'Winter', 'Spring'];

    const { container } = render(
      <Slider>
        {list.map((element) => (
          <div key={keygen()}>{element}</div>
        ))}
      </Slider>
    );

    const content = container.querySelector('div.slider');
    fireEvent.mouseDown(content, { clientX: 0 });
    fireEvent.mouseMove(content, { clientX: 1000 });
    fireEvent.mouseUp(content, { clientX: 1000 });
  });
});
afterEach(() => {
  cleanup();
});
