import React from 'react';
import PropTypes from 'prop-types';

import Slider from '~molecules/slider';
import Slide from '~molecules/carousel/default-slide';
import keygen from '~helpers/keygen';
import styles from './carousel.module.scss';

const Carousel = ({
  page = {},
  module = {},
  settings = {},
  CustomSlideComponent,
  gtmClass = '',
}) => (
  <div className={styles.carouselContainer || ''}>
    <Slider {...settings} gtmClass={gtmClass}>
      {module.items.map((item, index) => (
        <div key={keygen()} className={styles.carouselItem || ''}>
          {CustomSlideComponent !== undefined ? (
            <CustomSlideComponent item={item} gtmClass={gtmClass} />
          ) : (
            <Slide
              slideTitle={`${page.title}-carousel-${index + 1}`}
              item={item}
              gtmClass={gtmClass}
            />
          )}
        </div>
      ))}
    </Slider>
  </div>
);

Carousel.propTypes = {
  page: PropTypes.shape({
    title: PropTypes.string,
  }),
  module: PropTypes.shape({
    items: PropTypes.arrayOf(
      PropTypes.shape({
        title: PropTypes.string,
        content: PropTypes.string,
        primary_action: PropTypes.string,
        secondary_action: PropTypes.string,
      })
    ),
    name: PropTypes.string,
  }),
  settings: PropTypes.shape(PropTypes.object),
  CustomSlideComponent: PropTypes.element,
  gtmClass: PropTypes.string,
};

export default Carousel;
